package integrationtest;

import org.junit.*;
import org.openqa.selenium.*;
import org.openqa.selenium.support.ui.*;

/**
 * Einfacher Selenium-Test mit der Wikipedia-Webseite.<br>
 * Wahlweise ausfuehrbar mit manueller main()-Methode
 * oder automatisiert als JUnit-Test.
 */
public class SeleniumSimpleTest
{
   public static final String BROWSERNAME_KEY      = "_BROWSERNAME";
   public static final String WEBDRIVEREXEPATH_KEY = "_WEBDRIVEREXEPATH";

   /**
    * Manuell ausfuehrbarer Selenium-Test.<br>
    * @param args 1. Parameter leer fuer HtmlUnitDriver oder
    *                  FF, Chrome, Edge, IE oder Safari fuer gewuenschten Webbrowser.<br>
    *             2. Parameter leer fuer HtmlUnitDriver, FF und Safari;
    *                  fuer Chrome und IE wird Pfad zum externen WebDriver.exe benoetigt,
    *                  z.B. zu chromedriver.exe, iexploredriver.exe bzw. MicrosoftWebDriver.exe.<br>
    */
   public static void main( String[] args )
   {
      String browserName = null, webDriverExePath = null;
      if( args != null ) {
         if( args.length > 0 ) { browserName      = args[0]; }
         if( args.length > 1 ) { webDriverExePath = args[1]; }
      }
      testSelenium( browserName, webDriverExePath );
   }

   /**
    * Automatisiert ausfuehrbarer JUnit-Selenium-Test.<br>
    * Falls die Umgebungsvariablen _BROWSERNAME und _WEBDRIVEREXEPATH
    * gesetzt sind, kann darueber der gewuenschte Webbrowser definiert werden.<br>
    * _BROWSERNAME:      leer fuer HtmlUnitDriver oder
    *                    FF, Chrome, Edge, IE oder Safari fuer gewuenschten Webbrowser.<br>
    * _WEBDRIVEREXEPATH: leer fuer HtmlUnitDriver, FF und Safari;
    *                    fuer Chrome und IE wird Pfad zum externen WebDriver.exe benoetigt,
    *                    z.B. zu chromedriver.exe, iexploredriver.exe bzw. MicrosoftWebDriver.exe.<br>
    */
   @Test
   public void testSelenium()
   {
      String browserName      = System.getProperty( BROWSERNAME_KEY );
      String webDriverExePath = System.getProperty( WEBDRIVEREXEPATH_KEY );
      Assert.assertTrue( testSelenium( browserName, webDriverExePath ) );
   }

   private static boolean testSelenium( String browserName, String webDriverExePath )
   {
      final String url = "http://de.wikipedia.org";
      final String ttl = "Selenium \u2013 Wikipedia";

      // WebDriver starten:
      try( WebDriverWrapper wdwrap = new WebDriverWrapper( browserName, webDriverExePath ) ) {
         WebDriver webDriver = wdwrap.getWebDriver();
         WebDriverWait wait = new WebDriverWait( webDriver, 10 );

         // Webseite laden, Daten eintragen und Antwort anfordern:
         webDriver.get( url );
         WebElement element = wait.until( ExpectedConditions.presenceOfElementLocated( By.id( "searchInput" ) ) );
         String titelAbfrageseite = webDriver.getTitle();
         element.sendKeys( "Selenium" );
         element = webDriver.findElement( By.name( "go" ) );
         element.click();

         // Ergebnisse pruefen:
         boolean ok = wait.until( ExpectedConditions.titleIs( ttl ) ).booleanValue();
         String titelErgebnisseite = webDriver.getTitle();
         String hauptueberschrift  = webDriver.findElement( By.id( "firstHeading" ) ).getText();
         ok &= ttl.equals( titelErgebnisseite ) && "Selenium".equals( hauptueberschrift );
         System.out.println( "\n------------------------------------------------------------" );
         if( browserName != null ) {
            System.out.println( "Webbrowsername:           " + browserName );
         }
         System.out.println( "WebDriver:                " + webDriver.getClass().getSimpleName() );
         System.out.println( "Test-URL:                 " + url );
         System.out.println( "Titel der Abfrage-Seite:  " + titelAbfrageseite );
         System.out.println( "Titel der Ergebnis-Seite: " + titelErgebnisseite );
         System.out.println( "Hauptueberschrift:        " + hauptueberschrift );
         System.out.println( ( ok ) ? "OK" : "Fehler" );
         System.out.println( "------------------------------------------------------------\n" );
         return ok;
      }
   }
}
